openOBD Client by Jifeline Networks for Python 3

Release notes:

 - 1.11.11 : Fixed broken UiHandler method
 - 1.11.10 : Beta release

---------------------------------------------------------------


